# aind-sharepoint-service-client

## aind-sharepoint-service

Service to pull data from Sharepoint.



This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.4
- Package version: 0.0.4
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import aind_sharepoint_service_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import aind_sharepoint_service_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import aind_sharepoint_service_client
from aind_sharepoint_service_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = aind_sharepoint_service_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
with aind_sharepoint_service_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = aind_sharepoint_service_client.DefaultApi(api_client)
    subject_id = '805811' # str | 

    try:
        # Get Las 2020
        api_response = api_instance.get_las2020(subject_id)
        print("The response of DefaultApi->get_las2020:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->get_las2020: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_las2020**](docs/DefaultApi.md#get_las2020) | **GET** /las_2020/{subject_id} | Get Las 2020
*DefaultApi* | [**get_nsb2019**](docs/DefaultApi.md#get_nsb2019) | **GET** /nsb_2019/{subject_id} | Get Nsb 2019
*DefaultApi* | [**get_nsb2023**](docs/DefaultApi.md#get_nsb2023) | **GET** /nsb_2023/{subject_id} | Get Nsb 2023
*DefaultApi* | [**get_nsb_present**](docs/DefaultApi.md#get_nsb_present) | **GET** /nsb_present/{subject_id} | Get Nsb Present
*HealthcheckApi* | [**get_health**](docs/HealthcheckApi.md#get_health) | **GET** /healthcheck | Perform a Health Check


## Documentation For Models

 - [After1StInjection](docs/After1StInjection.md)
 - [After2NdInjection](docs/After2NdInjection.md)
 - [AindProjectName](docs/AindProjectName.md)
 - [AindSharepointServiceServerModelsNsb2019CraniotomyType](docs/AindSharepointServiceServerModelsNsb2019CraniotomyType.md)
 - [AindSharepointServiceServerModelsNsb2019EdemaSwelling](docs/AindSharepointServiceServerModelsNsb2019EdemaSwelling.md)
 - [AindSharepointServiceServerModelsNsb2019IacucProtocol](docs/AindSharepointServiceServerModelsNsb2019IacucProtocol.md)
 - [AindSharepointServiceServerModelsNsb2019ImplantIdCoverslipType](docs/AindSharepointServiceServerModelsNsb2019ImplantIdCoverslipType.md)
 - [AindSharepointServiceServerModelsNsb2019Inj1Retsetting](docs/AindSharepointServiceServerModelsNsb2019Inj1Retsetting.md)
 - [AindSharepointServiceServerModelsNsb2019Inj1Type](docs/AindSharepointServiceServerModelsNsb2019Inj1Type.md)
 - [AindSharepointServiceServerModelsNsb2019Inj2Retsetting](docs/AindSharepointServiceServerModelsNsb2019Inj2Retsetting.md)
 - [AindSharepointServiceServerModelsNsb2019Inj2Type](docs/AindSharepointServiceServerModelsNsb2019Inj2Type.md)
 - [AindSharepointServiceServerModelsNsb2019Laceration](docs/AindSharepointServiceServerModelsNsb2019Laceration.md)
 - [AindSharepointServiceServerModelsNsb2019LimsRequired](docs/AindSharepointServiceServerModelsNsb2019LimsRequired.md)
 - [AindSharepointServiceServerModelsNsb2019Limstaskflow](docs/AindSharepointServiceServerModelsNsb2019Limstaskflow.md)
 - [AindSharepointServiceServerModelsNsb2019Procedure](docs/AindSharepointServiceServerModelsNsb2019Procedure.md)
 - [AindSharepointServiceServerModelsNsb2019Sex](docs/AindSharepointServiceServerModelsNsb2019Sex.md)
 - [AindSharepointServiceServerModelsNsb2019SinusBleed](docs/AindSharepointServiceServerModelsNsb2019SinusBleed.md)
 - [AindSharepointServiceServerModelsNsb2019SurgeryStatus](docs/AindSharepointServiceServerModelsNsb2019SurgeryStatus.md)
 - [AindSharepointServiceServerModelsNsb2023CraniotomyType](docs/AindSharepointServiceServerModelsNsb2023CraniotomyType.md)
 - [AindSharepointServiceServerModelsNsb2023EdemaSwelling](docs/AindSharepointServiceServerModelsNsb2023EdemaSwelling.md)
 - [AindSharepointServiceServerModelsNsb2023IacucProtocol](docs/AindSharepointServiceServerModelsNsb2023IacucProtocol.md)
 - [AindSharepointServiceServerModelsNsb2023ImplantIdCoverslipType](docs/AindSharepointServiceServerModelsNsb2023ImplantIdCoverslipType.md)
 - [AindSharepointServiceServerModelsNsb2023Inj1Retsetting](docs/AindSharepointServiceServerModelsNsb2023Inj1Retsetting.md)
 - [AindSharepointServiceServerModelsNsb2023Inj1Type](docs/AindSharepointServiceServerModelsNsb2023Inj1Type.md)
 - [AindSharepointServiceServerModelsNsb2023Inj2Retsetting](docs/AindSharepointServiceServerModelsNsb2023Inj2Retsetting.md)
 - [AindSharepointServiceServerModelsNsb2023Inj2Type](docs/AindSharepointServiceServerModelsNsb2023Inj2Type.md)
 - [AindSharepointServiceServerModelsNsb2023Laceration](docs/AindSharepointServiceServerModelsNsb2023Laceration.md)
 - [AindSharepointServiceServerModelsNsb2023LimsRequired](docs/AindSharepointServiceServerModelsNsb2023LimsRequired.md)
 - [AindSharepointServiceServerModelsNsb2023Limstaskflow](docs/AindSharepointServiceServerModelsNsb2023Limstaskflow.md)
 - [AindSharepointServiceServerModelsNsb2023Procedure](docs/AindSharepointServiceServerModelsNsb2023Procedure.md)
 - [AindSharepointServiceServerModelsNsb2023Sex](docs/AindSharepointServiceServerModelsNsb2023Sex.md)
 - [AindSharepointServiceServerModelsNsb2023SinusBleed](docs/AindSharepointServiceServerModelsNsb2023SinusBleed.md)
 - [AindSharepointServiceServerModelsNsb2023SurgeryStatus](docs/AindSharepointServiceServerModelsNsb2023SurgeryStatus.md)
 - [Behavior](docs/Behavior.md)
 - [BehaviorAutotrainCurriculum](docs/BehaviorAutotrainCurriculum.md)
 - [BehaviorCurriculumVersion](docs/BehaviorCurriculumVersion.md)
 - [BehaviorDestination](docs/BehaviorDestination.md)
 - [BehaviorFiberPhotometry](docs/BehaviorFiberPhotometry.md)
 - [BehaviorFipMode](docs/BehaviorFipMode.md)
 - [BehaviorFirstFipStage](docs/BehaviorFirstFipStage.md)
 - [BehaviorFirstVideoRecordingStage](docs/BehaviorFirstVideoRecordingStage.md)
 - [BehaviorPlatform](docs/BehaviorPlatform.md)
 - [BehaviorType](docs/BehaviorType.md)
 - [BlackCement](docs/BlackCement.md)
 - [Burr1FiberType](docs/Burr1FiberType.md)
 - [Burr1Hemisphere](docs/Burr1Hemisphere.md)
 - [Burr1InjectionDevice](docs/Burr1InjectionDevice.md)
 - [Burr1IntendedCcfTarget](docs/Burr1IntendedCcfTarget.md)
 - [Burr1IntendedMeasurementBlue](docs/Burr1IntendedMeasurementBlue.md)
 - [Burr1IntendedMeasurementGreen](docs/Burr1IntendedMeasurementGreen.md)
 - [Burr1IntendedMeasurementIsosbestic](docs/Burr1IntendedMeasurementIsosbestic.md)
 - [Burr1IntendedMeasurementRed](docs/Burr1IntendedMeasurementRed.md)
 - [Burr1PerformDuring](docs/Burr1PerformDuring.md)
 - [Burr1SpinalLocation](docs/Burr1SpinalLocation.md)
 - [Burr1Status](docs/Burr1Status.md)
 - [Burr1VirusBiosafteyLevelBsl](docs/Burr1VirusBiosafteyLevelBsl.md)
 - [Burr2FiberType](docs/Burr2FiberType.md)
 - [Burr2Hemisphere](docs/Burr2Hemisphere.md)
 - [Burr2InjectionDevice](docs/Burr2InjectionDevice.md)
 - [Burr2IntendedCcfTarget](docs/Burr2IntendedCcfTarget.md)
 - [Burr2IntendedMeasurementBlue](docs/Burr2IntendedMeasurementBlue.md)
 - [Burr2IntendedMeasurementGreen](docs/Burr2IntendedMeasurementGreen.md)
 - [Burr2IntendedMeasurementIsosbestic](docs/Burr2IntendedMeasurementIsosbestic.md)
 - [Burr2IntendedMeasurementRed](docs/Burr2IntendedMeasurementRed.md)
 - [Burr2PerformDuring](docs/Burr2PerformDuring.md)
 - [Burr2SpinalLocation](docs/Burr2SpinalLocation.md)
 - [Burr2Status](docs/Burr2Status.md)
 - [Burr2VirusBiosafteyLevelBsl](docs/Burr2VirusBiosafteyLevelBsl.md)
 - [Burr3FiberType](docs/Burr3FiberType.md)
 - [Burr3Hemisphere](docs/Burr3Hemisphere.md)
 - [Burr3InjectionDevice](docs/Burr3InjectionDevice.md)
 - [Burr3IntendedCcfTarget](docs/Burr3IntendedCcfTarget.md)
 - [Burr3IntendedMeasurementBlue](docs/Burr3IntendedMeasurementBlue.md)
 - [Burr3IntendedMeasurementGreen](docs/Burr3IntendedMeasurementGreen.md)
 - [Burr3IntendedMeasurementIsosbestic](docs/Burr3IntendedMeasurementIsosbestic.md)
 - [Burr3IntendedMeasurementRed](docs/Burr3IntendedMeasurementRed.md)
 - [Burr3PerformDuring](docs/Burr3PerformDuring.md)
 - [Burr3Status](docs/Burr3Status.md)
 - [Burr3VirusBiosafetyLevelBsl](docs/Burr3VirusBiosafetyLevelBsl.md)
 - [Burr4FiberType](docs/Burr4FiberType.md)
 - [Burr4Hemisphere](docs/Burr4Hemisphere.md)
 - [Burr4InjectionDevice](docs/Burr4InjectionDevice.md)
 - [Burr4IntendedCcfTarget](docs/Burr4IntendedCcfTarget.md)
 - [Burr4IntendedMeasurementBlue](docs/Burr4IntendedMeasurementBlue.md)
 - [Burr4IntendedMeasurementGreen](docs/Burr4IntendedMeasurementGreen.md)
 - [Burr4IntendedMeasurementIsosbestic](docs/Burr4IntendedMeasurementIsosbestic.md)
 - [Burr4IntendedMeasurementRed](docs/Burr4IntendedMeasurementRed.md)
 - [Burr4PerformDuring](docs/Burr4PerformDuring.md)
 - [Burr4Status](docs/Burr4Status.md)
 - [Burr4VirusBiosafteyLevelBsl](docs/Burr4VirusBiosafteyLevelBsl.md)
 - [Burr5FiberType](docs/Burr5FiberType.md)
 - [Burr5Hemisphere](docs/Burr5Hemisphere.md)
 - [Burr5InjectionDevice](docs/Burr5InjectionDevice.md)
 - [Burr5IntendedCcfTarget](docs/Burr5IntendedCcfTarget.md)
 - [Burr5IntendedMeasurementBlue](docs/Burr5IntendedMeasurementBlue.md)
 - [Burr5IntendedMeasurementGreen](docs/Burr5IntendedMeasurementGreen.md)
 - [Burr5IntendedMeasurementIsosbestic](docs/Burr5IntendedMeasurementIsosbestic.md)
 - [Burr5IntendedMeasurementRed](docs/Burr5IntendedMeasurementRed.md)
 - [Burr5PerformDuring](docs/Burr5PerformDuring.md)
 - [Burr5Status](docs/Burr5Status.md)
 - [Burr5VirusBiosafteyLevelBsl](docs/Burr5VirusBiosafteyLevelBsl.md)
 - [Burr6FiberType](docs/Burr6FiberType.md)
 - [Burr6Hemisphere](docs/Burr6Hemisphere.md)
 - [Burr6InjectionDevice](docs/Burr6InjectionDevice.md)
 - [Burr6IntendedCcfTarget](docs/Burr6IntendedCcfTarget.md)
 - [Burr6IntendedMeasurementBlue](docs/Burr6IntendedMeasurementBlue.md)
 - [Burr6IntendedMeasurementGreen](docs/Burr6IntendedMeasurementGreen.md)
 - [Burr6IntendedMeasurementIsosbestic](docs/Burr6IntendedMeasurementIsosbestic.md)
 - [Burr6IntendedMeasurementRed](docs/Burr6IntendedMeasurementRed.md)
 - [Burr6PerformDuring](docs/Burr6PerformDuring.md)
 - [Burr6Status](docs/Burr6Status.md)
 - [Burr6VirusBiosafteyLevelBsl](docs/Burr6VirusBiosafteyLevelBsl.md)
 - [BurrHole1](docs/BurrHole1.md)
 - [BurrHole2](docs/BurrHole2.md)
 - [BurrHole3](docs/BurrHole3.md)
 - [BurrHole4](docs/BurrHole4.md)
 - [BurrHole5](docs/BurrHole5.md)
 - [BurrHole6](docs/BurrHole6.md)
 - [CareModuele](docs/CareModuele.md)
 - [Contusion](docs/Contusion.md)
 - [ContusionHematoma](docs/ContusionHematoma.md)
 - [CraniotomyPerformDuring](docs/CraniotomyPerformDuring.md)
 - [During1StInjection](docs/During1StInjection.md)
 - [During2NdInjection](docs/During2NdInjection.md)
 - [Durotomy](docs/Durotomy.md)
 - [ExudateSeverity](docs/ExudateSeverity.md)
 - [EyeAffected](docs/EyeAffected.md)
 - [EyeIssue](docs/EyeIssue.md)
 - [FiberImplant1Length](docs/FiberImplant1Length.md)
 - [FiberImplant2Length](docs/FiberImplant2Length.md)
 - [FiberImplant3Length](docs/FiberImplant3Length.md)
 - [FiberImplant4Length](docs/FiberImplant4Length.md)
 - [FiberImplant5Length](docs/FiberImplant5Length.md)
 - [FiberImplant6Length](docs/FiberImplant6Length.md)
 - [FirstRoundInjIsoLevel](docs/FirstRoundInjIsoLevel.md)
 - [FirstRoundInjWorkstation](docs/FirstRoundInjWorkstation.md)
 - [Firstroundiontoissue](docs/Firstroundiontoissue.md)
 - [Firstroundiontonumber](docs/Firstroundiontonumber.md)
 - [Firstroundnanojectnumber](docs/Firstroundnanojectnumber.md)
 - [FollowUpNanojectNumber](docs/FollowUpNanojectNumber.md)
 - [FollowUpWorkstation](docs/FollowUpWorkstation.md)
 - [FolowUpIontoNumber](docs/FolowUpIontoNumber.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Headpost](docs/Headpost.md)
 - [HeadpostPerformDuring](docs/HeadpostPerformDuring.md)
 - [HeadpostType](docs/HeadpostType.md)
 - [HealthCheck](docs/HealthCheck.md)
 - [Hematoma](docs/Hematoma.md)
 - [HpDurotomy](docs/HpDurotomy.md)
 - [HpIsoLevel](docs/HpIsoLevel.md)
 - [HpLocation](docs/HpLocation.md)
 - [HpPerferations](docs/HpPerferations.md)
 - [HpWorkStation](docs/HpWorkStation.md)
 - [InitialIontoNumber](docs/InitialIontoNumber.md)
 - [InitialNanojectNumber](docs/InitialNanojectNumber.md)
 - [InitialWorkStation](docs/InitialWorkStation.md)
 - [Inj1Angle](docs/Inj1Angle.md)
 - [Inj1Hemisphere](docs/Inj1Hemisphere.md)
 - [Inj1Round](docs/Inj1Round.md)
 - [Inj2Angle](docs/Inj2Angle.md)
 - [Inj2Hemisphere](docs/Inj2Hemisphere.md)
 - [Inj2Round](docs/Inj2Round.md)
 - [Inj3Retsetting](docs/Inj3Retsetting.md)
 - [Inj3Type](docs/Inj3Type.md)
 - [Inj4Retsetting](docs/Inj4Retsetting.md)
 - [Inj4Type](docs/Inj4Type.md)
 - [Inj5Retsetting](docs/Inj5Retsetting.md)
 - [Inj5Type](docs/Inj5Type.md)
 - [Inj6Retsetting](docs/Inj6Retsetting.md)
 - [Inj6Type](docs/Inj6Type.md)
 - [Iontonumberhpinj](docs/Iontonumberhpinj.md)
 - [Issue](docs/Issue.md)
 - [LASBctype](docs/LASBctype.md)
 - [LASDoseroute](docs/LASDoseroute.md)
 - [LASIcvlims](docs/LASIcvlims.md)
 - [LASIcvroute1](docs/LASIcvroute1.md)
 - [LASIcvroute2](docs/LASIcvroute2.md)
 - [LASIcvroute3](docs/LASIcvroute3.md)
 - [LASIcvroute4](docs/LASIcvroute4.md)
 - [LASIcvroute5](docs/LASIcvroute5.md)
 - [LASLimsproject](docs/LASLimsproject.md)
 - [LASLimsworkflow](docs/LASLimsworkflow.md)
 - [LASLimsworkflow2](docs/LASLimsworkflow2.md)
 - [LASPostfix](docs/LASPostfix.md)
 - [LASProjectid](docs/LASProjectid.md)
 - [LASProtocol](docs/LASProtocol.md)
 - [LASReqpro1](docs/LASReqpro1.md)
 - [LASReqpro2](docs/LASReqpro2.md)
 - [LASReqpro3](docs/LASReqpro3.md)
 - [LASRequeststatus2](docs/LASRequeststatus2.md)
 - [LASRoeye1](docs/LASRoeye1.md)
 - [LASRoeye2](docs/LASRoeye2.md)
 - [LASRoeye3](docs/LASRoeye3.md)
 - [LASRoeye4](docs/LASRoeye4.md)
 - [LASRoeye5](docs/LASRoeye5.md)
 - [LASRolims](docs/LASRolims.md)
 - [LASRosop](docs/LASRosop.md)
 - [LASSpecies](docs/LASSpecies.md)
 - [LASTamFrequency](docs/LASTamFrequency.md)
 - [LASTmpFrequency](docs/LASTmpFrequency.md)
 - [LASWhereToObtainSubstanceRo](docs/LASWhereToObtainSubstanceRo.md)
 - [LASWheretoobtainsubstanceIcv](docs/LASWheretoobtainsubstanceIcv.md)
 - [Las2020List](docs/Las2020List.md)
 - [LightCycle](docs/LightCycle.md)
 - [Lightcycle](docs/Lightcycle.md)
 - [LimsProjectCode](docs/LimsProjectCode.md)
 - [Limsproject](docs/Limsproject.md)
 - [NSB2019List](docs/NSB2019List.md)
 - [NSB2023List](docs/NSB2023List.md)
 - [OfBurrHoles](docs/OfBurrHoles.md)
 - [PhysiologyType](docs/PhysiologyType.md)
 - [PreviouslyInjected](docs/PreviouslyInjected.md)
 - [ProcedureCategory](docs/ProcedureCategory.md)
 - [ProcedureSlots](docs/ProcedureSlots.md)
 - [ProjectId](docs/ProjectId.md)
 - [Projectid](docs/Projectid.md)
 - [Protocol](docs/Protocol.md)
 - [Scabbing](docs/Scabbing.md)
 - [SecondRoundInjIsoLevel](docs/SecondRoundInjIsoLevel.md)
 - [SecondRoundIontoIssue](docs/SecondRoundIontoIssue.md)
 - [SecondRoundWorkstation](docs/SecondRoundWorkstation.md)
 - [Secondroundiontonumber](docs/Secondroundiontonumber.md)
 - [Secondroundnanojectnumber](docs/Secondroundnanojectnumber.md)
 - [Thermistor](docs/Thermistor.md)
 - [TouchUpStatus](docs/TouchUpStatus.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [Well](docs/Well.md)
 - [WindowClarity](docs/WindowClarity.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




